package esac.archive.lpf.common.constants.client;

/**
 * Utility class to specify HTTP constants (servlet param names, status codes, etc...) contents.
 * 
 * @author Monica F Barreiro Copyright (c) 2013 - European Space Agency
 */
public class LpfHttpConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected LpfHttpConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    // /////////////////////////////////////////////////////////////////////////
    // / TARGET HTTP status codes
    // /////////////////////////////////////////////////////////////////////////

    // Target Resolver Service Not Available
    public static final int STATUS_CODE_TARGET_RESOLVER_SERVICE_NOT_AVAILABLE = 998;

    // Target Not Found Status code
    public static final int STATUS_CODE_TARGET_NOT_FOUND = 999;

    // /////////////////////////////////////////////////////////////////////////
    // / CLIENT HTTP status codes
    // /////////////////////////////////////////////////////////////////////////

    /** The request has succeeded */
    public static final int REQUEST_OK = 200;

    /** BAD REQUEST: The request cannot be fulfilled due to bad syntax. */
    public static final int BAD_REQUEST = 400;

    /**
     * NOT FOUND. The requested resource could not be found but may be available again in the
     * future.
     */
    public static final int NOT_FOUND = 404;

    /**
     * Unauthorized: The request requires user authentication. If the request already included
     * Authorization credentials, then the 401 response indicates that authorization has been
     * refused for those credentials.
     */
    public static final int UNAUTHORIZED = 401;

    // /////////////////////////////////////////////////////////////////////////
    // / Servlet parameters
    // /////////////////////////////////////////////////////////////////////////

    /** Login servlet params. */
    public static final String SERVLET_PARAM_USERNAME = "USERNAME";
    public static final String SERVLET_PARAM_PASSWORD = "PASSWORD";
    public static final String SERVLET_PARAM_USER_ACTION = "SUBMIT";

    public static final String SERVLET_PARAM_SUBMIT_CHECK = "CHECK";
    public static final String SERVLET_PARAM_SUBMIT_LOGIN = "LOGIN";
    public static final String SERVLET_PARAM_SUBMIT_LOGOUT = "LOGOUT";

    public static final String SERVLET_PARAM_URL = "URL";


    /** Text to write in results file when value is null. */
    public static final String DEFAULT_DISPLAY_STRING_FOR_NULL_VALUE = "null";

}
